//#define XERR
#include "mri.ih"

double MRI::vSensitivity(size_t idx) const
{
    return d_sensitivity.value();
}
